short_benchmark_text_for_translation = {
# Afrikaans
"af": "Om 'n nuwe taal te leer kan uitdagend wees, maar dit is ook opwindend. Dit help ons om met mense van verskillende kulture te verbind en die wêreld beter te verstaan. Elke nuwe taal wat ons leer, gee ons 'n vars perspektief en maak nuwe geleenthede oop.",

# Albanian
"sq": "Të mësuarit e një gjuhe të re mund të jetë sfiduese, por gjithashtu është emocionuese. Na ndihmon të lidhemi me njerëz nga kultura të ndryshme dhe të kuptojmë më mirë botën. Çdo gjuhë e re që mësojmë na jep një perspektivë të re dhe hap mundësi të reja.",

# Amharic
"am": "አዲስ ቋንቋ ማማር ሊያስቸግር ይችላል፣ ግን ደግሞ አስደሳች ነው። ከተለያዩ ባህሎች የመጡ ሰዎች ጋር ለመገናኘትና ዓለምን በተሻለ ለማስተዋል ይረዳል። ሁሉም አዲስ ቋንቋ ያለን አዳዲስ አስተሳሰብ ይሰጠናልና አዲስ ዕድሎችን ይከፍትልናል።",

# Arabic
"ar": "قد يكون تعلم لغة جديدة أمرًا صعبًا، ولكنه أيضًا مثير. إنه يساعدنا على التواصل مع أشخاص من ثقافات مختلفة وفهم العالم بشكل أفضل. كل لغة جديدة نتعلمها تمنحنا منظورًا جديدًا وتفتح أمامنا فرصًا جديدة.",

# Armenian
"hy": "Նոր լեզու սովորելը կարող է բարդ լինել, բայց դա նաև հետաքրքիր է։ Այն օգնում է մեզ կապվել տարբեր մշակույթների մարդկանց հետ և ավելի լավ հասկանալ աշխարհը։ Ամեն նոր լեզու, որ մենք սովորում ենք, տալիս է մեզ նոր տեսանկյուն և բացում նոր հնարավորություններ։",

# Azerbaijani
"az": "Yeni bir dili öyrənmək çətin ola bilər, amma həm də həyəcanvericidir. O, bizi müxtəlif mədəniyyətlərdən olan insanlarla əlaqələndirməyə və dünyanı daha yaxşı anlamağa kömək edir. Öyrəndiyimiz hər yeni dil bizə yeni bir baxış bucağı verir və yeni imkanlar açır.",

# Basque
"eu": "Hizkuntza berri bat ikastea erronka izan daiteke, baina zirraragarria ere bada. Hainbat kulturatako jendearekin konektatzen eta mundua hobeto ulertzen laguntzen digu. Ikasten dugun hizkuntza berri bakoitzak ikuspegi berri bat eskaintzen digu eta aukera berriak irekitzen ditu.",

# Belarusian
"be": "Вывучэнне новай мовы можа быць складаным, але гэта таксама захапляльна. Гэта дапамагае нам звязвацца з людзьмі з розных культур і лепш разумець свет. Кожная новая мова, якую мы вывучаем, дае нам новы погляд і адкрывае новыя магчымасці.",

# Bengali
"bn": "নতুন ভাষা শেখা চ্যালেঞ্জিং হতে পারে, কিন্তু এটি উত্তেজনাপূর্ণও। এটি আমাদের বিভিন্ন সংস্কৃতির মানুষের সাথে সংযোগ করতে এবং বিশ্বকে আরও ভালোভাবে বুঝতে সহায়তা করে। আমরা যে প্রতিটি নতুন ভাষা শিখি, তা আমাদের একটি নতুন দৃষ্টিভঙ্গি দেয় এবং নতুন সুযোগ খুলে দেয়।",

# Bosnian
"bs": "Učenje novog jezika može biti izazovno, ali je i uzbudljivo. Pomaže nam da se povežemo s ljudima iz različitih kultura i bolje razumijemo svijet. Svaki novi jezik koji naučimo daje nam novu perspektivu i otvara nove mogućnosti.",

# Breton
"br": "Deskiñ ur yezh nevez a c'hall bezañ diaes, met ivez tener. E sikour a ra ac'hanomp da gevreañ gant tud eus sevenadurioù disheñvel ha da gompren gwelloc'h ar bed. Pep yezh nevez a zeskomp a ro deomp ur sell nevez hag a zigor doareoù nevez.",

# Bulgarian
"bg": "Да се научи нов език може да бъде предизвикателство, но е и вълнуващо. Той ни помага да се свържем с хора от различни култури и да разберем по-добре света. Всеки нов език, който научаваме, ни дава нова перспектива и отваря нови възможности.",

# Burmese
"my": "ဘာသာစကားအသစ်တစ်ခုကို သင်ယူခြင်းသည် စိန်ခေါ်မှုဖြစ်နိုင်ပါသည်၊ သို့သော် ၎င်းသည် စိတ်လှုပ်ရှားဖွယ်လည်း ဖြစ်ပါသည်။ ၎င်းက ကွဲပြားခြားနားသည့် ယဉ်ကျေးမှုများရှိသူများနှင့် ဆက်သွယ်နိုင်ရန်နှင့် ကမ္ဘာကြီးကို ပိုမိုနားလည်ရန် ကူညီပေးပါသည်။ ကျွန်ုပ်တို့ သင်ယူသည့် ဘာသာစကားအသစ်တိုင်းသည် ကျွန်ုပ်တို့ကို သစ်လွင်သော အမြင်တစ်ခု ပေးစွမ်းပြီး အခွင့်အလမ်းအသစ်များကို ဖွင့်ပေးပါသည်။",

# Catalan
"ca": "Aprendre un nou idioma pot ser un repte, però també és emocionant. Ens ajuda a connectar amb persones de diferents cultures i a comprendre millor el món. Cada nou idioma que aprenem ens dóna una nova perspectiva i obre noves oportunitats.",

# Chichewa
"ny": "Kuphunzira chinenero chatsopano kungakhale kovuta, koma kumakhala kosangalatsa. Zimatithandiza kulumikizana ndi anthu ochokera kumayiko osiyanasiyana ndikumvetsetsa dziko bwino. Chinenero chilichonse chatsopano chimene timaphunzira chimatipatsa malingaliro atsopano ndi kutsegula mwayi watsopano.",

# Chinese
"zh": "学习一门新语言可能具有挑战性，但它也令人兴奋。它帮助我们与来自不同文化的人联系，更好地理解世界。我们学习的每一种新语言都为我们提供新的视角，开启新的机会。",

# Corsican
"co": "Amparà una nova lingua pò esse sfida, ma hè ancu eccitante. Ci aiuta à cunnettassi cù persone di culture diverse è à capisce megliu u mondu. Ogni nova lingua chì amparemu ci dà una nova perspettiva è apre nuove opportunità.",

# Croatian
"hr": "Učenje novog jezika može biti izazovno, ali je i uzbudljivo. Pomaže nam da se povežemo s ljudima iz različitih kultura i bolje razumijemo svijet. Svaki novi jezik koji naučimo daje nam novu perspektivu i otvara nove mogućnosti.",

# Czech
"cs": "Naučit se nový jazyk může být náročné, ale také vzrušující. Pomáhá nám to spojit se s lidmi z různých kultur a lépe porozumět světu. Každý nový jazyk, který se naučíme, nám poskytuje nový pohled a otevírá nové příležitosti.",

# Danish
"da": "At lære et nyt sprog kan være udfordrende, men det er også spændende. Det hjælper os med at forbinde med mennesker fra forskellige kulturer og forstå verden bedre. Hvert nyt sprog vi lærer giver os et nyt perspektiv og åbner nye muligheder.",

# Dutch
"nl": "Een nieuwe taal leren kan een uitdaging zijn, maar het is ook spannend. Het helpt ons om contact te maken met mensen uit verschillende culturen en de wereld beter te begrijpen. Elke nieuwe taal die we leren geeft ons een nieuw perspectief en opent nieuwe mogelijkheden.",

# English
"en": "Learning a new language can be challenging, but it is also exciting. It helps us connect with people from different cultures and understand the world better. Every new language we learn gives us a fresh perspective and opens up new opportunities.",

# Esperanto
"eo": "Lerni novan lingvon povas esti defio, sed ĝi estas ankaŭ ekscita. Ĝi helpas nin konekti kun homoj el diversaj kulturoj kaj pli bone kompreni la mondon. Ĉiu nova lingvo, kiun ni lernas, donas al ni freŝan perspektivon kaj malfermas novajn ŝancojn.",

# Estonian
"et": "Uue keele õppimine võib olla väljakutse, kuid see on ka põnev. See aitab meil ühenduda inimestega erinevatest kultuuridest ja maailma paremini mõista. Iga uus keel, mida õpime, annab meile värske vaatenurga ja avab uusi võimalusi.",

# Fijian
"fj": "Na vulica e dua na vosa vou e rawa ni ka ni bolebole, ia e taleitaki talega. E vukei keda meda semati kei ira na tamata mai na veimatanitu duidui ka kila vinaka cake na vuravura. Na vosa vou kece eda vulica e solia vei keda e dua na rai vou ka dolava na madigi vou.",

# Finnish
"fi": "Uuden kielen oppiminen voi olla haastavaa, mutta se on myös jännittävää. Se auttaa meitä yhdistämään eri kulttuureista tulevia ihmisiä ja ymmärtämään maailmaa paremmin. Jokainen uusi kieli, jonka opimme, antaa meille uuden näkökulman ja avaa uusia mahdollisuuksia.",

# French
"fr": "Apprendre une nouvelle langue peut être difficile, mais c'est aussi excitant. Cela nous aide à nous connecter avec des personnes de différentes cultures et à mieux comprendre le monde. Chaque nouvelle langue que nous apprenons nous offre une nouvelle perspective et ouvre de nouvelles opportunités.",

# Galician
"gl": "Aprender un novo idioma pode ser un desafío, pero tamén é emocionante. Axúdanos a conectarnos con persoas de diferentes culturas e a comprender mellor o mundo. Cada novo idioma que aprendemos dános unha nova perspectiva e abre novas oportunidades.",

# Georgian
"ka": "ახალი ენის სწავლა შეიძლება რთული იყოს, მაგრამ ასევე საინტერესოა. ეს გვეხმარება დავუკავშირდეთ სხვადასხვა კულტურის ადამიანებს და უკეთ გავიგოთ მსოფლიო. ყოველი ახალი ენა, რომელსაც ვსწავლობთ, გვაძლევს ახალ პერსპექტივას და ხსნის ახალ შესაძლებლობებს.",

# German
"de": "Eine neue Sprache zu lernen kann herausfordernd sein, aber es ist auch aufregend. Es hilft uns, mit Menschen aus verschiedenen Kulturen in Kontakt zu treten und die Welt besser zu verstehen. Jede neue Sprache, die wir lernen, gibt uns eine neue Perspektive und eröffnet neue Möglichkeiten.",

# Greek
"el": "Η εκμάθηση μιας νέας γλώσσας μπορεί να είναι πρόκληση, αλλά είναι επίσης συναρπαστική. Μας βοηθά να συνδεθούμε με ανθρώπους από διαφορετικούς πολιτισμούς και να κατανοήσουμε καλύτερα τον κόσμο. Κάθε νέα γλώσσα που μαθαίνουμε μας δίνει μια νέα προοπτική και ανοίγει νέες ευκαιρίες.",

# Gujarati
"gu": "નવી ભાષા શીખવી પડકારજનક હોઈ શકે છે, પરંતુ તે રોમાંચક પણ છે. તે આપણને વિવિધ સંસ્કૃતિઓના લોકો સાથે જોડવામાં અને વિશ્વને વધુ સારી રીતે સમજવામાં મદદ કરે છે. દરેક નવી ભાષા જે આપણે શીખીએ છીએ તે આપણને નવી દૃષ્ટિ આપે છે અને નવા અવસરો ખોલે છે.",

# Haitian
"ht": "Aprann yon nouvo lang ka yon defi, men li enteresan tou. Li ede nou konekte ak moun ki soti nan diferan kilti epi konprann mond lan pi byen. Chak nouvo lang nou aprann ba nou yon nouvo pèspektiv e louvri nouvo opòtinite.",

# Hebrew
"he": "לימוד שפה חדשה יכול להיות מאתגר, אבל זה גם מרגש. זה עוזר לנו להתחבר עם אנשים מתרבויות שונות ולהבין את העולם טוב יותר. כל שפה חדשה שאנחנו לומדים מעניקה לנו פרספקטיבה חדשה ופותחת הזדמנויות חדשות.",

# Hindi
"hi": "नई भाषा सीखना चुनौतीपूर्ण हो सकता है, लेकिन यह रोमांचक भी है। यह हमें विभिन्न संस्कृतियों के लोगों से जुड़ने और दुनिया को बेहतर समझने में मदद करता है। हर नई भाषा जो हम सीखते हैं, वह हमें एक नया दृष्टिकोण देती है और नए अवसर खोलती है।",

# Hungarian
"hu": "Egy új nyelv megtanulása kihívást jelenthet, de izgalmas is. Segít kapcsolatba lépni különböző kultúrákból származó emberekkel és jobban megérteni a világot. Minden új nyelv, amit megtanulunk, új perspektívát nyújt és új lehetőségeket nyit meg.",

# Icelandic
"is": "Að læra nýtt tungumál getur verið krefjandi, en það er líka spennandi. Það hjálpar okkur að tengjast fólki frá mismunandi menningarheimum og skilja heiminn betur. Hvert nýtt tungumál sem við lærum gefur okkur nýtt sjónarhorn og opnar ný tækifæri.",

# Indonesian
"id": "Mempelajari bahasa baru bisa menjadi tantangan, tetapi juga menyenangkan. Ini membantu kita terhubung dengan orang-orang dari berbagai budaya dan memahami dunia dengan lebih baik. Setiap bahasa baru yang kita pelajari memberi kita perspektif baru dan membuka peluang baru.",

# Irish
"ga": "Is féidir go mbeadh sé dúshlánach teanga nua a fhoghlaim, ach tá sé spreagúil freisin. Cabhraíonn sé linn ceangal le daoine ó chultúir éagsúla agus an domhan a thuiscint níos fearr. Tugann gach teanga nua a fhoghlaimímid peirspictíocht úr dúinn agus osclaíonn sé deiseanna nua.",

# Italian
"it": "Imparare una nuova lingua può essere impegnativo, ma è anche emozionante. Ci aiuta a connetterci con persone di culture diverse e a comprendere meglio il mondo. Ogni nuova lingua che impariamo ci dà una nuova prospettiva e apre nuove opportunità.",

# Japanese
"ja": "新しい言語を学ぶことは挑戦的ですが、それもまた刺激的です。それは私たちが異なる文化の人々とつながり、世界をよりよく理解するのを助けます。私たちが学ぶ新しい言語はすべて、新しい視点を与え、新しい機会を開きます。",

# Javanese
"jv": "Sinau basa anyar bisa dadi tantangan, nanging uga nyenengake. Iki mbantu kita nyambung karo wong saka macem-macem budaya lan ngerti jagad iki luwih apik. Saben basa anyar sing kita sinaoni menehi perspektif anyar lan mbukak kesempatan anyar.",

# Kannada
"kn": "ಹೊಸ ಭಾಷೆಯನ್ನು ಕಲಿಯುವುದು ಸವಾಲಾಗಿರಬಹುದು, ಆದರೆ ಇದು ರೋಚಕವೂ ಆಗಿದೆ. ಇದು ನಮಗೆ ವಿಭಿನ್ನ ಸಂಸ್ಕೃತಿಗಳಿಂದ ಬಂದ ಜನರೊಂದಿಗೆ ಸಂಪರ್ಕ ಸಾಧಿಸಲು ಮತ್ತು ಲೋಕವನ್ನು ಉತ್ತಮವಾಗಿ ಅರ್ಥಮಾಡಿಕೊಳ್ಳಲು ಸಹಾಯ ಮಾಡುತ್ತದೆ. ನಾವು ಕಲಿಯುವ ಪ್ರತಿ ಹೊಸ ಭಾಷೆಯು ನಮಗೆ ಹೊಸ ದೃಷ್ಟಿಕೋಣವನ್ನು ನೀಡುತ್ತದೆ ಮತ್ತು ಹೊಸ ಅವಕಾಶಗಳನ್ನು ತೆರೆಯುತ್ತದೆ.",

# Kazakh
"kk": "Жаңа тілді үйрену қиын болуы мүмкін, бірақ бұл өте қызықты. Бұл бізге әртүрлі мәдениеттерден келген адамдармен байланысуға және әлемді жақсырақ түсінуге көмектеседі. Біз үйренетін әрбір жаңа тіл бізге жаңа көзқарас береді және жаңа мүмкіндіктер ашады.",

# Khmer
"km": "ការរៀនភាសាថ្មីអាចមានភាពបញ្ហាប្រឈម ប៉ុន្តែវាក៏គួរឱ្យរំភើបដែរ។ វាជួយឱ្យយើងភ្ជាប់ទំនាក់ទំនងជាមួយមនុស្សពីវប្បធម៌ផ្សេងៗគ្នា និងយល់ពីពិភពលោកបានល្អប្រសើរជាងមុន។ ភាសាថ្មីនីមួយៗដែលយើងរៀនផ្តល់ឱ្យយើងនូវទស្សនៈថ្មី និងបើកឱកាសថ្មីៗ។",

# Kinyarwanda
"rw": "Kwigira ururimi rushya bishobora kuba imbogamizi, ariko birashimishije. Bituma dushobora guhuza n'abantu b'umuco utandukanye no gusobanukirwa isi neza. Buri rurimi rushya twiga ruduha indi sura kandi rukadufungurira andi mahirwe.",

# Kirghiz
"ky": "Жаңы тилди үйрөнүү кыйын болушу мүмкүн, бирок бул кызыктуу да. Бул бизге ар түрдүү маданияттардагы адамдар менен байланышуубузга жана дүйнөнү жакшыраак түшүнүүгө жардам берет. Биз үйрөнгөн ар бир жаңы тил бизге жаңы көз караш берип, жаңы мүмкүнчүлүктөрдү ачат.",

# Korean
"ko": "새로운 언어를 배우는 것은 도전적일 수 있지만, 그것은 또한 흥미롭습니다. 그것은 우리가 다른 문화의 사람들과 연결하고 세계를 더 잘 이해하는 데 도움이 됩니다. 우리가 배우는 모든 새로운 언어는 우리에게 새로운 관점을 제공하고 새로운 기회를 열어줍니다.",

# Kurdish
"ku": "Zimanekî nû fêr bûn dikare birêwêtî be, lê jî hêsan e. Ew alîkarî dike me bi kesên ji çandên cuda ve têkilî bike û cîhanê baştir fêm bike. Her zimanekî nû ku em fêr dibin, ji bo me dîtina nû dide û deriyên nû vedike.",

# Lao
"lo": "ການຮຽນພາສາໃໝ່ອາດຈະທ້າທາຍ, ແຕ່ມັນກໍມີຄວາມຕື່ນເຕັ້ນເຊັ່ນກັນ. ມັນຊ່ວຍໃຫ້ພວກເຮົາເຊື່ອມຕໍ່ກັບຜູ້ຄົນຈາກວັດທະນະທຳທີ່ແຕກຕ່າງ ແລະເຂົ້າໃຈໂລກໄດ້ດີຂຶ້ນ. ທຸກພາສາໃໝ່ທີ່ພວກເຮົາຮຽນຈະໃຫ້ມຸມມອງໃຫມ່ແລະເປີດໂອກາດໃໝ່ໆ.",

# Latin
"la": "Linguam novam discere difficile esse potest, sed etiam excitans est. Nos adiuvat ut cum hominibus ex diversis culturis conectamur et mundum melius intellegamus. Quaeque nova lingua quam discimus nobis novam perspicientiam dat et novas opportunitates aperit.",

# Latvian
"lv": "Jaunas valodas apguve var būt izaicinājums, bet tas ir arī aizraujoši. Tas palīdz mums sazināties ar cilvēkiem no dažādām kultūrām un labāk izprast pasauli. Katrs jauns valoda, ko apgūstam, sniedz mums jaunu skatījumu un paver jaunas iespējas.",

# Lithuanian
"lt": "Naujos kalbos mokymasis gali būti iššūkis, bet tai taip pat įdomu. Tai padeda mums susisiekti su žmonėmis iš skirtingų kultūrų ir geriau suprasti pasaulį. Kiekviena nauja kalba, kurią išmokstame, suteikia mums naują požiūrį ir atveria naujas galimybes.",

# Luxembourgish
"lb": "Eng nei Sprooch léieren kann eng Erausfuerderung sinn, mee et ass och spannend. Et hëlleft eis mat Leit aus verschiddene Kulturen ze verbannen an d'Welt besser ze verstoen. All nei Sprooch déi mir léieren, gëtt eis eng nei Perspektiv a mécht nei Méiglechkeeten op.",

# Macedonian
"mk": "Учењето нов јазик може да биде предизвик, но исто така е и возбудливо. Ни помага да се поврземе со луѓе од различни култури и подобро да го разбереме светот. Секој нов јазик што го учиме ни дава нова перспектива и отвора нови можности.",

# Malagasy
"mg": "Ny fianarana fiteny vaovao dia mety ho fanamby, saingy koa mahaliana. Manampy antsika hifandray amin'ny olona avy amin'ny kolontsaina samihafa izy io ary hahatakatra tsara kokoa izao tontolo izao. Ny fiteny vaovao rehetra ianarantsika dia manome fomba fijery vaovao ho antsika ary manokatra varavarana vaovao.",

# Malay
"ms": "Mempelajari bahasa baru boleh menjadi mencabar, tetapi ia juga menarik. Ia membantu kita berhubung dengan orang dari pelbagai budaya dan memahami dunia dengan lebih baik. Setiap bahasa baru yang kita pelajari memberi kita perspektif baharu dan membuka peluang baharu.",

# Malayalam
"ml": "ഒരു പുതിയ ഭാഷയെ പഠിക്കുന്നത് വെല്ലുവിളിയാകും, പക്ഷേ അത് രസകരവും ആണ്. അത് നമ്മെ വിവിധ സംസ്കാരങ്ങളിലുള്ള ആളുകളുമായി ബന്ധിപ്പിക്കാനും ലോകത്തെ കൂടുതൽ മനസിലാക്കാനുമാണ് സഹായിക്കുന്നത്. നാം പഠിക്കുന്ന ഓരോ പുതിയ ഭാഷയും ഞങ്ങൾക്ക് പുതിയ കാഴ്ചപ്പാട് നൽകുകയും പുതിയ അവസരങ്ങൾ തുറക്കുകയും ചെയ്യുന്നു.",

# Maltese
"mt": "It-tagħlim ta' lingwa ġdida jista' jkun ta' sfida, iżda huwa wkoll eċċitanti. Jgħinna nikkonnettjaw ma' nies minn kulturi differenti u nifhmu aħjar id-dinja. Kull lingwa ġdida li nitgħallmu tagħtina perspettiva ġdida u tiftaħ opportunitajiet ġodda.",

# Maori
"mi": "Ko te ako i tētahi reo hou he wero pea, engari he mea whakahihiri anō hoki. Ka āwhina i a tātou ki te hono ki ngā tāngata nō ngā ahurea rerekē, me te mārama ake ki te ao. Ia reo hou e ako ana tātou, ka hoatu he tirohanga hou ki a tātou, ka whakatuwhera i ngā ara hou.",

# Marathi
"mr": "नवीन भाषा शिकणे आव्हानात्मक असू शकते, परंतु ती रोमांचक देखील आहे. हे आपल्याला विविध संस्कृतींच्या लोकांशी जोडण्यास आणि जग अधिक चांगल्या प्रकारे समजून घेण्यास मदत करते. आपण शिकत असलेली प्रत्येक नवीन भाषा आपल्याला नवीन दृष्टिकोन देते आणि नवीन संधी उघडते.",

# Mongolian
"mn": "Шинэ хэлийг сурах нь сорилттой байж болох ч бас сонирхолтой. Энэ нь бидэнд өөр өөр соёлын хүмүүстэй холбогдож, дэлхийг илүү сайн ойлгоход тусалдаг. Бидний сурч буй шинэ хэл бүр бидэнд шинэ өнцөг өгч, шинэ боломжуудыг нээдэг.",

# Nepali
"ne": "नयाँ भाषा सिक्न गाह्रो हुन सक्छ, तर यो रोमाञ्चक पनि छ। यसले हामीलाई विभिन्न संस्कृतिका मानिसहरूलाई जोड्न र संसारलाई राम्रोसँग बुझ्न मद्दत गर्छ। हामीले सिकेका प्रत्येक नयाँ भाषाले हामीलाई नयाँ दृष्टिकोण दिन्छ र नयाँ अवसरहरू खोल्छ।",

# Norwegian
"no": "Å lære et nytt språk kan være utfordrende, men det er også spennende. Det hjelper oss å knytte bånd med mennesker fra forskjellige kulturer og forstå verden bedre. Hvert nye språk vi lærer gir oss et nytt perspektiv og åpner nye muligheter.",

# Norwegian Bokmål
"nb": "Å lære et nytt språk kan være utfordrende, men det er også spennende. Det hjelper oss å knytte bånd med mennesker fra forskjellige kulturer og forstå verden bedre. Hvert nye språk vi lærer gir oss et nytt perspektiv og åpner nye muligheter.",

# Norwegian Nynorsk
"nn": "Å lære eit nytt språk kan vere utfordrande, men det er også spennande. Det hjelper oss å knyte band med menneske frå ulike kulturar og forstå verda betre. Kvart nye språk vi lærer, gjev oss eit nytt perspektiv og opnar nye moglegheiter.",

# Occitan
"oc": "Aprene una lenga novèla pòt èsser un desfís, mas es tanben passionant. Nos ajuda a connectar amb de personas de culturas diferentas e a melhor comprendre lo mond. Cada lenga novèla que aprendèm nos dona una novèla perspectiva e dubrís de novèlas oportunitats.",

# Pashto
"ps": "د يوې نوې ژبې زده کړه ستونزمنه کېدی شي، خو دا هم زړه پورې ده. دا موږ سره د بېلابېلو کلتورونو له خلکو سره د اړیکو په جوړولو او نړۍ په ښه درک کولو کې مرسته کوي. هره نوې ژبه چې موږ يې زده کوو، موږ ته نوی لید راکوي او نوي فرصتونه پرانیزي.",

# Persian
"fa": "یادگیری یک زبان جدید می‌تواند چالش‌برانگیز باشد، اما همچنین هیجان‌انگیز است. این به ما کمک می‌کند با افراد از فرهنگ‌های مختلف ارتباط برقرار کنیم و جهان را بهتر درک کنیم. هر زبان جدیدی که یاد می‌گیریم، دیدگاه تازه‌ای به ما می‌دهد و فرصت‌های جدیدی را باز می‌کند.",

# Polish
"pl": "Nauka nowego języka może być wyzwaniem, ale jest również ekscytująca. Pomaga nam nawiązać kontakt z ludźmi z różnych kultur i lepiej zrozumieć świat. Każdy nowy język, którego się uczymy, daje nam nową perspektywę i otwiera nowe możliwości.",

# Portuguese
"pt": "Aprender um novo idioma pode ser desafiador, mas também é emocionante. Isso nos ajuda a nos conectar com pessoas de diferentes culturas e a entender melhor o mundo. Cada novo idioma que aprendemos nos dá uma nova perspectiva e abre novas oportunidades.",

# Punjabi
"pa": "ਇੱਕ ਨਵੀਂ ਭਾਸ਼ਾ ਸਿੱਖਣਾ ਚੁਣੌਤੀਪੂਰਨ ਹੋ ਸਕਦਾ ਹੈ, ਪਰ ਇਹ ਰੋਮਾਂਚਕ ਵੀ ਹੈ। ਇਹ ਸਾਨੂੰ ਵੱਖ-ਵੱਖ ਸੰਸਕਿਰਤੀਆਂ ਦੇ ਲੋਕਾਂ ਨਾਲ ਜੁੜਨ ਅਤੇ ਦੁਨੀਆਂ ਨੂੰ ਬਿਹਤਰ ਢੰਗ ਨਾਲ ਸਮਝਣ ਵਿੱਚ ਮਦਦ ਕਰਦਾ ਹੈ। ਹਰ ਨਵੀਂ ਭਾਸ਼ਾ ਜੋ ਅਸੀਂ ਸਿੱਖਦੇ ਹਾਂ, ਉਹ ਸਾਨੂੰ ਇੱਕ ਨਵਾਂ ਦ੍ਰਿਸ਼ਟੀਕੋਣ ਦਿੰਦੀ ਹੈ ਅਤੇ ਨਵੇਂ ਮੌਕੇ ਖੋਲ੍ਹਦੀ ਹੈ।",

# Quechua
"qu": "Runasimita yachayqa llank'aqmi, ichaqa kusisqa. Manam aswan sumaqmi runakunawan rimayta, kay pacha allin yuyayta. Yachaykunaqa qhawaymanta allin kanmi, k'ana kachkanmi.",

# Romanian
"ro": "Învățarea unei limbi noi poate fi o provocare, dar este și interesantă. Ne ajută să ne conectăm cu oameni din diferite culturi și să înțelegem mai bine lumea. Fiecare limbă nouă pe care o învățăm ne oferă o nouă perspectivă și deschide noi oportunități.",

# Russian
"ru": "Изучение нового языка может быть сложным, но это также увлекательно. Это помогает нам связываться с людьми из разных культур и лучше понимать мир. Каждый новый язык, который мы изучаем, дает нам новый взгляд и открывает новые возможности.",

# Samoan
"sm": "O le aʻoaʻoina o se gagana fou e mafai ona luʻitauina, ae e manaia foi. E fesoasoani ia i tatou e fesoʻotaʻi ma tagata mai aganuʻu eseese ma malamalama atili i le lalolagi. O gagana fou taʻitasi tatou te aʻoaʻoina e avatua ia i tatou se vaaiga fou ma tatala ai avanoa fou.",

# Sanskrit
"sa": "नवीनां भाषां ज्ञातुं कठिनं भवति, परं तदा रोमाञ्चकरं चास्ति। सा अस्मान् विभिन्नसंस्कृतिविदां जनानां सह सम्बद्धुं विश्वं च बोधितुं साहाय्यं करोति। प्रत्येकां नवीनां भाषां यां वयं ज्ञास्यामः, साऽस्मभ्यं नूतनं दृष्टिकोणं ददाति अवसरानपि नूतनान् उद्घाटयति।",

# Scottish Gaelic
"gd": "Faodaidh ionnsachadh cànain ùir a bhith dùbhlanach, ach tha e cuideachd inntinneach. Bidh e a' cuideachadh leinn ceangal ri daoine bho dhiofar chultaran agus tuigse nas fheàrr fhaighinn air an t-saoghal. Tha gach cànan ùr a dh'ionnsaicheas sinn a' toirt sealladh ùr dhuinn agus a' fosgladh chothroman ùra.",

# Serbian
"sr": "Učenje novog jezika može biti izazovno, ali je i uzbudljivo. Pomaže nam da se povežemo sa ljudima iz različitih kultura i bolje razumemo svet. Svaki novi jezik koji naučimo daje nam novu perspektivu i otvara nove mogućnosti.",

# Sinhala
"si": "නව භාෂාවක් ඉගෙන ගැනීම අභියෝගයකුත් හැකිද? නමුත් එය කුතුහලය ජනිත කරයි. එය අපට විවිධ සංස්කෘතිකයන්ගෙන් පැමිණි පුද්ගලයින් සමඟ සම්බන්ධ වීමට සහ ලෝකය වඩා හොඳින් තේරුම් ගැනීමට උපකාරී වේ. අපි ඉගෙන ගන්නා සෑම නව භාෂාවක්ම අපට නව දැක්මක් සපයයි සහ නව අවස්ථා විවෘත කරයි.",

# Slovak
"sk": "Naučiť sa nový jazyk môže byť náročné, ale je to aj vzrušujúce. Pomáha nám spojiť sa s ľuďmi z rôznych kultúr a lepšie pochopiť svet. Každý nový jazyk, ktorý sa naučíme, nám poskytuje nový pohľad a otvára nové príležitosti.",

# Slovenian
"sl": "Učenje novega jezika je lahko izziv, a je tudi vznemirljivo. Pomaga nam vzpostaviti stik z ljudmi iz različnih kultur in bolje razumeti svet. Vsak nov jezik, ki se ga naučimo, nam ponudi nov pogled in odpre nove priložnosti.",

# Somali
"so": "Barashada luqad cusub waxay noqon kartaa caqabad, laakiin sidoo kale waa xiiso leh. Waxay naga caawisaa inaan ku xirno dad ka kala yimid dhaqamo kala duwan oo aan si fiican u fahanno adduunka. Luuqad kasta oo cusub oo aan barano waxay noo siisaa aragti cusub waxayna furaysaa fursado cusub.",

# Southern Sotho
"st": "Ho ithuta puo e ncha ho ka ba thata, empa ho boetse ho thabisa. Ho re thusa ho hokahana le batho ba tsoang lichabeng tse fapaneng le ho utloisisa lefatše hamolemo. Puo e 'ngoe le e 'ngoe e ncha eo re ithutang eona e re fa pono e ncha mme e bula menyetla e mecha.",

# Spanish
"es": "Aprender un nuevo idioma puede ser un desafío, pero también es emocionante. Nos ayuda a conectarnos con personas de diferentes culturas y a comprender mejor el mundo. Cada nuevo idioma que aprendemos nos da una nueva perspectiva y abre nuevas oportunidades.",

# Sundanese
"su": "Diajar basa anyar tiasa janten tangtangan, tapi ogé pikaresepeun. Éta ngabantosan urang nyambung sareng jalma-jalma ti budaya anu béda sareng ngartos dunya langkung saé. Unggal basa anyar anu urang pelajari masihan urang sudut pandang anyar sareng muka kasempetan anyar.",

# Swahili
"sw": "Kujifunza lugha mpya kunaweza kuwa changamoto, lakini pia inasisimua. Inatusaidia kuungana na watu kutoka tamaduni tofauti na kuelewa ulimwengu bora zaidi. Kila lugha mpya tunayoijifunza hutupa mtazamo mpya na kufungua fursa mpya.",

# Swedish
"sv": "Att lära sig ett nytt språk kan vara utmanande, men det är också spännande. Det hjälper oss att knyta band med människor från olika kulturer och förstå världen bättre. Varje nytt språk vi lär oss ger oss ett nytt perspektiv och öppnar nya möjligheter.",

# Tagalog
"tl": "Ang pag-aaral ng bagong wika ay maaaring maging mapanghamon, ngunit ito rin ay nakapupukaw. Tinutulungan tayo nitong makipag-ugnayan sa mga tao mula sa iba't ibang kultura at mas maunawaan ang mundo. Ang bawat bagong wika na ating natututuhan ay nagbibigay sa atin ng bagong pananaw at nagbubukas ng mga bagong pagkakataon.",

# Tajik
"tg": "Омӯзиши забони нав метавонад душвор бошад, аммо он ҳамчунин шавқовар аст. Он ба мо кӯмак мекунад, ки бо одамон аз фарҳангҳои гуногун пайваст шавем ва ҷаҳонро беҳтар дарк кунем. Ҳар як забони наве, ки меомӯзем, ба мо назари нав мебахшад ва имкониятҳои нав мекушояд.",

# Tamil
"ta": "புதிய மொழியை கற்றல் சவாலாக இருக்கலாம், ஆனால் அது மகிழ்ச்சிகரமாகவும் இருக்கும். இது நம்மை பல்வேறு கலாச்சாரங்களிலிருந்து வந்த மக்களுடன் இணைக்கிறது மற்றும் உலகத்தை மேல் புரிந்து கொள்ள உதவுகிறது. நாம் கற்றுக்கொள்வது ஒவ்வொரு புதிய மொழியும் நமக்கு புதிய பார்வையை அளிக்கிறது மற்றும் புதிய வாய்ப்புகளை திறக்கிறது.",

# Tatar
"tt": "Яңа телне өйрәнү кыен булырга мөмкин, ләкин ул шулай ук мавыктыргыч. Ул безгә төрле мәдәниятләрдән кешеләр белән аралашырга һәм дөньяны яхшырак аңларга ярдәм итә. Без өйрәнгән һәр яңа тел безгә яңа караш бирә һәм яңа мөмкинлекләр ача.",

# Telugu
"te": "కొత్త భాషను నేర్చుకోవడం సవాలుగా ఉండవచ్చు, కానీ ఇది ఆసక్తికరంగా కూడా ఉంటుంది. ఇది మనకు వివిధ సంస్కృతులకు చెందిన వ్యక్తులతో సంబంధాలను మెరుగుపరచడానికి మరియు ప్రపంచాన్ని బాగా అర్థం చేసుకోవడానికి సహాయపడుతుంది. మనం నేర్చుకునే ప్రతి కొత్త భాష మనకు కొత్త దృక్కోణాన్ని అందిస్తుంది మరియు కొత్త అవకాశాలను తెరుస్తుంది.",

# Thai
"th": "การเรียนรู้ภาษาใหม่อาจเป็นเรื่องที่ท้าทาย แต่ก็น่าตื่นเต้นเช่นกัน มันช่วยให้เราเชื่อมต่อกับผู้คนจากวัฒนธรรมที่แตกต่างกันและเข้าใจโลกได้ดีขึ้น ทุกภาษาที่เราเรียนรู้จะทำให้เรามีมุมมองใหม่และเปิดโอกาสใหม่ ๆ",

# Tibetan
"bo": "གསར་བར་སྐད་ཡིག་གཅིག་སྦྱོང་བ་ལྷག་པའི་རྩོལ་བ་བྱས་རུང་། དེ་ཡང་སྐྱིད་པོ་རེད། འདི་གིས་ང་ཚོ་ལ་རྣམ་གྲངས་རང་དབང་གི་གནས་སྟངས་སྐྱེ་བའི་སྤྱོད་ལམ་ལུགས་གསར་པའི་བྱ་བར་གཅིག་སྦྱོང་བ་ལྷག་པའི་བདེ་བར་གྱིས་བརྙེས་པ་ཡིན།",

# Tigrinya
"ti": "ሓድሽ ቋንቋ ምምሃር ብዙሕ ይኽኣል ከቢድ ይርከብ፣ ግን ድሓን ምልክት እዩ። ከተለያዩ ባህላት ዘለዎም ሰባት ምስ ምርካብና ዓለምን ክንረዳ ይንረዳና። እያን ሓድሽ ቋንቋ ዘንምሃር ናይ ሓድሽ ክብረት ይሃብና እንተደሊና መደብ ሓደ ይእክብልና።",

# Tswana
"tn": "Go ithuta puo e ntšha go ka nna kgwetlho, fela gape go a kgatlha. Go re thusa go golaganya le batho ba ba tswang mo ditso tse di farologaneng le go tlhaloganya lefatshe botoka. Puo nngwe le nngwe e ntšha e re ithutang e re naya pono e ntšha le go bula ditshono tse disha.",

# Turkish
"tr": "Yeni bir dil öğrenmek zor olabilir, ama aynı zamanda heyecan vericidir. Bu, farklı kültürlerden insanlarla bağlantı kurmamıza ve dünyayı daha iyi anlamamıza yardımcı olur. Öğrendiğimiz her yeni dil bize yeni bir bakış açısı kazandırır ve yeni fırsatlar açar.",

# Turkmen
"tk": "Täze dili öwrenmek kyn bolup biler, emma ol hem tolgundyryjydyr. Ol bizi dürli medeniýetlerden gelen adamlar bilen birleşdirmäge we dünýäni has gowy düşünmäge kömek edýär. Öwrenýän her bir täze dilimiz bize täze garaýyş berýär we täze mümkinçilikleri açýar.",

# Uyghur
"ug": "يېڭى تىلنى ئۆگەنىش قىيىن بولۇشى مۇمكىن، لېكىن ئۇ ھەم قىزىقارلىق. بۇ بىزگە خېلى سۈرئەتتە پەرىقلەرنى چۈشىنىپ، دۇنياغا يېڭىچە قاراشقا يول قويىدۇ. بىز ئۆگەنگەن ھەرقانداق يېڭى تىل بىزگە يېڭى كۆرۈش بىرىپ، يېڭى پۇرسەتلەرنى ئېچىدۇ.",

# Ukrainian
"uk": "Вивчення нової мови може бути складним, але водночас захоплюючим. Це допомагає нам спілкуватися з людьми з різних культур і краще розуміти світ. Кожна нова мова, яку ми вивчаємо, дає нам новий погляд і відкриває нові можливості.",

# Urdu
"ur": "نئی زبان سیکھنا مشکل ہو سکتا ہے، لیکن یہ بھی دلچسپ ہے۔ یہ ہمیں مختلف ثقافتوں کے لوگوں سے جوڑنے اور دنیا کو بہتر سمجھنے میں مدد کرتا ہے۔ ہر نئی زبان جو ہم سیکھتے ہیں، ہمیں ایک نیا نقطہ نظر دیتی ہے اور نئے مواقع کھولتی ہے۔",

# Uzbek
"uz": "Yangi tilni o'rganish qiyin bo'lishi mumkin, lekin bu ham hayajonli. Bu bizga turli madaniyatlardan odamlar bilan bog'lanishimizga va dunyoni yaxshiroq tushunishimizga yordam beradi. O'rganayotgan har bir yangi til bizga yangi nuqtai nazar beradi va yangi imkoniyatlar ochadi.",

# Vietnamese
"vi": "Học một ngôn ngữ mới có thể là một thách thức, nhưng nó cũng rất thú vị. Nó giúp chúng ta kết nối với những người từ các nền văn hóa khác nhau và hiểu rõ hơn về thế giới. Mỗi ngôn ngữ mới mà chúng ta học sẽ mang đến cho chúng ta một góc nhìn mới và mở ra những cơ hội mới.",

# Welsh
"cy": "Gall dysgu iaith newydd fod yn heriol, ond mae hefyd yn gyffrous. Mae'n ein helpu i gysylltu â phobl o ddiwylliannau gwahanol ac yn deall y byd yn well. Mae pob iaith newydd a ddysgwn yn rhoi persbectif newydd i ni ac yn agor cyfleoedd newydd.",

# Wolof
"wo": "Jàng taal bu bees moy nekk lu metti, waaye itam dafay metti ci xol. Dina nu jëkkalante ak nit ñi ci cosaan yu bari te nuy wax sa wax ji. Taal bu bees bu nu jànge day nu may wone boppam te day ubbil boppam.",

# Xhosa
"xh": "Ukufunda ulwimi olutsha kunokuba ngumngeni, kodwa kuyachulumanca. Kusinceda ukudibanisa nabantu abavela kwiinkcubeko ezahlukeneyo kwaye siqonde ihlabathi ngcono. Lonke ulwimi olutsha esilufundayo lusinika umbono omtsha kwaye luvula amathuba amatsha.",

# Yiddish
"yi": "לערנען אַ ניי שפּראַך קען זיין אַ אַרויסרופן, אָבער עס איז אויך יקסייטינג. עס העלפּס אונדז פאַרבינדן מיט מענטשן פֿון פאַרשידענע קולטורן און פֿאַרשטיין די וועלט בעסער. יעדער ניי שפּראַך וואָס מיר לערנען, גיט אונדז אַ פריש פּערספּעקטיוו און עפֿנט נייַע מעגלעכקייטן.",

# Yoruba
"yo": "Kíkọ èdè tuntun lè jẹ́ ìṣòro, ṣùgbọ́n ó tún jẹ́ ohun ìdùnnú. Ó ràn wá lọ́wọ́ láti bá ènìyàn láti ọ̀nà àṣà àìmọ̀ràn ṣe pọ̀ mọ́ra àti láti lóye ayé dáadáa. Gbogbo èdè tuntun tí a bá kọ́, ó fún wa ní ojú-ọ̀nà tuntun tí ó sì ṣí ìlúṣọ́ tuntun.",

# Zulu
"zu": "Ukufunda ulimi olusha kungaba yinselele, kodwa kuyajabulisa. Kusisiza ukuba sixhumane nabantu abavela kumasiko ahlukahlukene futhi siqonde kangcono umhlaba. Ulimi ngalunye olusha esilufundayo lusinika umbono omusha futhi luvula amathuba amasha.",

}